ErrorInfo class

媒体加载任务错误信息类 用于封装预加载任务的错误详情

Constructors

ErrorInfo({required String taskId, required String urlOrVid, required String errorCode, String? errorMsg, String? errorExtra})
构造函数
ErrorInfo.fromJson(Map<String, dynamic> json)
从Map创建实例
factory

Properties

errorCode → String
错误码
final
errorExtra → String?
额外错误信息(可选)
final
errorMsg → String?
错误信息(可选)
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId → String
任务ID
final
urlOrVid → String
URL或VID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
转换为Map
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited