MultiBitratesMode enum

默认配置,播放和预加载默认码率

default mode, play and preload default bitrate of a stream

Inheritance
Available extensions

Values

MultiBitratesMode_Default → const MultiBitratesMode

默认配置,播放和预加载默认码率

default mode, play and preload default bitrate of a stream

MultiBitratesMode_FCPrio → const MultiBitratesMode

首帧优先配置,起播视频默认播放已完成预加载的码率

First frame cost (FC) priority, decrease first frame cost. only play bitrate of the hls stream which has been preloaded.

MultiBitratesMode_FC_AND_SMOOTH → const MultiBitratesMode

兼顾首帧和播放平滑,切换前后(moveToNext)的视频码率一致,且兼顾首帧性能

First frame and play smooth, play the same bitrate before and after moveToNext

MultiBitratesMode_SmoothPrio → const MultiBitratesMode

播放平滑优先配置,起播视频默认播放前一个视频的码率

Play Smooth priority, play the same bitrate before and after moveToNext.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MultiBitratesMode>
A constant List of the values in this enum, in order of their declaration.