VidSts class

VID+STS视频源类 用于处理基于VID和STS凭证的视频源

Inheritance

Constructors

VidSts({required String vid, required String accessKeyId, required String accessKeySecret, required String securityToken, String? region, VidSourceConfig? config})
构造函数 vid 视频ID,必需 accessKeyId 访问密钥ID,必需 accessKeySecret 访问密钥Secret,必需 securityToken 安全令牌,必需 region 区域信息,可选 config VID源配置,可选

Properties

accessKeyId ↔ String
访问密钥ID
getter/setter pair
accessKeySecret ↔ String
访问密钥Secret
getter/setter pair
config ↔ VidSourceConfig?
VID源配置(可选)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
quality → String?
重写获取视频质量 VID+STS类型不指定特定质量
no setteroverride
region ↔ String?
区域信息(可选)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityToken ↔ String
安全令牌
getter/setter pair
vid ↔ String
视频ID
getter/setter pair
videoType → VideoSourceType
重写获取视频源类型 返回VID+STS类型的视频源标识
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
重写将视频源信息转换为JSON映射 返回包含VID+STS相关信息的Map对象
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited